
import pytest

@pytest.fixture
def node_json():
    return """
{
    "id": "MONDO:0020121",
    "category": "biolink:Disease",
    "name": "muscular dystrophy",
    "full_name": null,
    "deprecated": null,
    "description": "Muscular dystrophy (MD) refers to a group of more than 30 genetic diseases characterized by progressive weakness and degeneration of the skeletal muscles that control movement. Some forms of MD are seen in newborns, infants or children, while others have late-onset and may not appear until middle age or later. The disorders differ in terms of the distribution and extent of muscle weakness (some forms of MD also affect cardiac muscle), age of onset, rate of progression, and pattern of inheritance. The prognosis for people with MD varies according to the type and progression of the disorder. There is no specific treatment to stop or reverse any form of MD. Treatment is supportive and may include physical therapy, respiratory therapy, speech therapy, orthopedic appliances used for support, corrective orthopedic surgery, and medicationsincluding corticosteroids, anticonvulsants (seizure medications), immunosuppressants, and antibiotics. Some individuals may need assisted ventilation to treat respiratory muscle weaknessor a pacemaker for cardiac (heart)abnormalities.",
    "xref": [
        "DOID:9884",
        "GARD:7922",
        "ICD10CM:G71.0",
        "ICD9:359.1",
        "MEDGEN:44527",
        "MESH:D009136",
        "MedDRA:10028356",
        "NANDO:1200486",
        "NANDO:2100233",
        "NCIT:C84910",
        "Orphanet:98473",
        "SCTID:73297009",
        "UMLS:C0026850",
        "icd11.foundation:1464662404"
    ],
    "provided_by": "phenio_nodes",
    "in_taxon": null,
    "in_taxon_label": null,
    "symbol": null,
    "synonym": null,
    "broad_synonym": null,
    "exact_synonym": null,
    "narrow_synonym": null,
    "related_synonym": null,
    "subsets": [
        "disease_grouping|gard_rare|ordo_group_of_disorders|otar|rare"
    ],
    "uri": "http://purl.obolibrary.org/obo/MONDO_0020121",
    "iri": null,
    "namespace": "MONDO",
    "has_phenotype": null,
    "has_phenotype_label": null,
    "has_phenotype_closure": null,
    "has_phenotype_closure_label": null,
    "has_phenotype_count": 0,
    "has_descendant": [
        "MONDO:0013162",
        "MONDO:0971171",
        "MONDO:0018951",
        "MONDO:0035648",
        "MONDO:0010678",
        "MONDO:0011787",
        "MONDO:0013158",
        "MONDO:0019950",
        "MONDO:0013159",
        "MONDO:0011968",
        "MONDO:0010400",
        "MONDO:0012277",
        "MONDO:0000727",
        "MONDO:0012215",
        "MONDO:0016108",
        "MONDO:0000173",
        "MONDO:0024530",
        "MONDO:0009675",
        "MONDO:0024607",
        "MONDO:0017892",
        "MONDO:0007614",
        "MONDO:0014071",
        "MONDO:0013049",
        "MONDO:0030456",
        "MONDO:0023671",
        "MONDO:0029133",
        "MONDO:0018281",
        "MONDO:0021569",
        "MONDO:0015151",
        "MONDO:0030712",
        "MONDO:0018939",
        "MONDO:1040033",
        "MONDO:0009683",
        "MONDO:0011246",
        "MONDO:0014788",
        "MONDO:0013155",
        "MONDO:0010676",
        "MONDO:0009690",
        "MONDO:0700285",
        "MONDO:0033556",
        "MONDO:0035649",
        "MONDO:0014683",
        "MONDO:0009678",
        "MONDO:0010311",
        "MONDO:0958233",
        "MONDO:0010870",
        "MONDO:0000172",
        "MONDO:0013297",
        "MONDO:0010884",
        "MONDO:0023595",
        "MONDO:0009677",
        "MONDO:0035647",
        "MONDO:0010401",
        "MONDO:0010677",
        "MONDO:0014782",
        "MONDO:0008030",
        "MONDO:0014140",
        "MONDO:0021018",
        "MONDO:0018759",
        "MONDO:0011266",
        "MONDO:0008034",
        "MONDO:0100228",
        "MONDO:0012193",
        "MONDO:0014489",
        "MONDO:0029136",
        "MONDO:0013550",
        "MONDO:0012248",
        "MONDO:0012652",
        "MONDO:0013904",
        "MONDO:0009676",
        "MONDO:0012410",
        "MONDO:0013160",
        "MONDO:0957270",
        "MONDO:0014896",
        "MONDO:0012138",
        "MONDO:0013178",
        "MONDO:0025193",
        "MONDO:0010684",
        "MONDO:0008028",
        "MONDO:0014654",
        "MONDO:0024545",
        "MONDO:0030355",
        "MONDO:0012127",
        "MONDO:0010680",
        "MONDO:0009682",
        "MONDO:0018949",
        "MONDO:0011271",
        "MONDO:0009685",
        "MONDO:0009680",
        "MONDO:0016049",
        "MONDO:0000171",
        "MONDO:0013440",
        "MONDO:0018280",
        "MONDO:0012262",
        "MONDO:0958236",
        "MONDO:0012270",
        "MONDO:0014142",
        "MONDO:0020121",
        "MONDO:0016971",
        "MONDO:0018276",
        "MONDO:0008031",
        "MONDO:0011362",
        "MONDO:0014538",
        "MONDO:0958353",
        "MONDO:0016107",
        "MONDO:0015152",
        "MONDO:0018278",
        "MONDO:0011423",
        "MONDO:0958234",
        "MONDO:0100531",
        "MONDO:0009181",
        "MONDO:0013222",
        "MONDO:0011688",
        "MONDO:0008409",
        "MONDO:0013161",
        "MONDO:0018371",
        "MONDO:0012034",
        "MONDO:0035646",
        "MONDO:0008116",
        "MONDO:0008029",
        "MONDO:0001347",
        "MONDO:0013177",
        "MONDO:0024771",
        "MONDO:0011181",
        "MONDO:0014900",
        "MONDO:0014141",
        "MONDO:0030354",
        "MONDO:0034022",
        "MONDO:0958077",
        "MONDO:0009681",
        "MONDO:0029135",
        "MONDO:0013071",
        "MONDO:0008049",
        "MONDO:0958195",
        "MONDO:0011028",
        "MONDO:0958235",
        "MONDO:0011170",
        "MONDO:0018006",
        "MONDO:0009667",
        "MONDO:0010679",
        "MONDO:0014101",
        "MONDO:0030014",
        "MONDO:0958176",
        "MONDO:0014144",
        "MONDO:0023204",
        "MONDO:0011466",
        "MONDO:0018098",
        "MONDO:0014877",
        "MONDO:0013835",
        "MONDO:0035650",
        "MONDO:0008056",
        "MONDO:0009364",
        "MONDO:0013157",
        "MONDO:0014676",
        "MONDO:0016830",
        "MONDO:0975918",
        "MONDO:0008050",
        "MONDO:0700075",
        "MONDO:0800318",
        "MONDO:0014800",
        "MONDO:0011721",
        "MONDO:0014474",
        "MONDO:0013154",
        "MONDO:0009679",
        "MONDO:0020336",
        "MONDO:0035432",
        "MONDO:0018370",
        "MONDO:0014023",
        "MONDO:0012699",
        "MONDO:0012130",
        "MONDO:0010912",
        "MONDO:0013221",
        "MONDO:0011925",
        "MONDO:0021083",
        "MONDO:0019951",
        "MONDO:0014022",
        "MONDO:0013390",
        "MONDO:0011486",
        "MONDO:0014977",
        "MONDO:0013156",
        "MONDO:0000355",
        "MONDO:0012310",
        "MONDO:0013072",
        "MONDO:0013677",
        "MONDO:0016097",
        "MONDO:0014120",
        "MONDO:0004495",
        "MONDO:0010675",
        "MONDO:0100584",
        "MONDO:0016106",
        "MONDO:0012286",
        "MONDO:0013686",
        "MONDO:0020793",
        "MONDO:0030134",
        "MONDO:0014945",
        "MONDO:0019398",
        "MONDO:0800209"
    ],
    "has_descendant_label": [
        "autosomal recessive limb-girdle muscular dystrophy type 2N",
        "muscular dystrophy, limb-girdle, autosomal recessive 29",
        "distal myopathy with vocal cord weakness",
        "juvenile-onset Steinert myotonic dystrophy",
        "muscular dystrophy, progressive Pectorodorsal",
        "autosomal recessive limb-girdle muscular dystrophy type 2I",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A6",
        "congenital muscular dystrophy",
        "muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B1",
        "autosomal recessive limb-girdle muscular dystrophy type 2D",
        "X-linked scapuloperoneal muscular dystrophy",
        "myofibrillar myopathy 4",
        "scapuloperoneal myopathy",
        "myofibrillar myopathy 3",
        "autosomal dominant distal myopathy",
        "muscular dystrophy-dystroglycanopathy, type C",
        "Bethlem myopathy 1A",
        "autosomal recessive limb-girdle muscular dystrophy type 2A",
        "congenital muscular dystrophy with cataracts and intellectual disability",
        "autosomal recessive myogenic arthrogryposis multiplex congenita",
        "congenital fibrosis of extraocular muscles",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 11",
        "DPM3-congenital disorder of glycosylation",
        "muscular dystrophy, limb-girdle, autosomal recessive 27",
        "oculopharyngodistal myopathy 3",
        "muscular dystrophy, limb-girdle, autosomal dominant 4",
        "congenital muscular dystrophy with hyperlaxity",
        "Emery-Dreifuss muscular dystrophy 2, autosomal dominant",
        "muscular dystrophy, limb-girdle, autosomal dominant",
        "oculopharyngodistal myopathy 4",
        "muscle-eye-brain disease",
        "congenital muscular dystrophy without intellectual disability",
        "autosomal recessive limb-girdle muscular dystrophy type 2H",
        "megaconial type congenital muscular dystrophy",
        "autosomal recessive limb-girdle muscular dystrophy type 2W",
        "muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B3",
        "muscular dystrophy, Hemizygous lethal type",
        "congenital myasthenic syndrome 10",
        "DMD-related muscular dystrophy",
        "muscular dystrophy-dystroglycanopathy (congenital with impaired intellectual development), type B, 15",
        "adult-onset Steinert myotonic dystrophy",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A9",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A, 4",
        "Becker muscular dystrophy",
        "Bethlem myopathy 1B",
        "tibial muscular dystrophy",
        "muscular dystrophy-dystroglycanopathy, type B",
        "autosomal dominant limb-girdle muscular dystrophy type 1H",
        "muscular dystrophy, scapulohumeral",
        "congenital myotonic dystrophy",
        "autosomal recessive limb-girdle muscular dystrophy type 2C",
        "childhood-onset Steinert myotonic dystrophy",
        "X-linked myopathy with postural muscle atrophy",
        "muscular dystrophy, Mabry type",
        "autosomal recessive limb-girdle muscular dystrophy type 2X",
        "facioscapulohumeral muscular dystrophy 1",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A14",
        "autosomal dominant limb-girdle muscular dystrophy type 1D (DNAJB6)",
        "childhood-onset progressive contractures-limb-girdle weakness-muscle dystrophy syndrome",
        "myotonic dystrophy type 2",
        "muscular dystrophy, pseudohypertrophic, with Internalized capillaries",
        "LAMA2-related muscular dystrophy",
        "autosomal dominant limb-girdle muscular dystrophy type 1G",
        "limb-girdle muscular dystrophy due to POMK deficiency",
        "muscular dystrophy, limb-girdle, autosomal recessive 23",
        "distal myopathy with posterior leg and anterior hand involvement",
        "autosomal recessive limb-girdle muscular dystrophy type 2K",
        "autosomal recessive limb-girdle muscular dystrophy type 2L",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 8",
        "autosomal recessive limb-girdle muscular dystrophy type 2B",
        "Finnish upper limb-onset distal myopathy",
        "muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B2",
        "muscular dystrophy, limb-girdle, autosomal recessive 28",
        "congenital muscular dystrophy-respiratory failure-skin abnormalities-joint hyperlaxity syndrome",
        "muscular dystrophy-dystroglycanopathy type B6",
        "congenital muscular dystrophy due to LMNA mutation",
        "oculopharyngodistal myopathy",
        "X-linked myopathy with excessive autophagy",
        "muscular dystrophy, Barnes type",
        "Ullrich congenital muscular dystrophy 2",
        "Miyoshi muscular dystrophy 1",
        "facioscapulohumeral muscular dystrophy 4, digenic",
        "autosomal recessive limb-girdle muscular dystrophy type 2J",
        "X-linked Emery-Dreifuss muscular dystrophy",
        "muscular dystrophy, congenital, with rapid progression",
        "distal myopathy",
        "rigid spine muscular dystrophy 1",
        "Miyoshi myopathy",
        "congenital muscular dystrophy-infantile cataract-hypogonadism syndrome",
        "congenital myopathy, Paradas type",
        "muscular dystrophy-dystroglycanopathy, type A",
        "autosomal recessive limb-girdle muscular dystrophy type 2P",
        "muscle-eye-brain disease with bilateral multicystic leucodystrophy",
        "fibrosis of extraocular muscles, congenital, 3c",
        "Ullrich congenital muscular dystrophy 1C",
        "Tukel syndrome",
        "autosomal recessive limb-girdle muscular dystrophy type 2T",
        "muscular dystrophy",
        "limb-girdle muscular dystrophy",
        "muscular dystrophy-dystroglycanopathy",
        "facioscapulohumeral muscular dystrophy 2",
        "myopathy, myofibrillar, 9, with early respiratory failure",
        "fibrosis of extraocular muscles, congenital, 5",
        "intermediate collagen VI-related muscular dystrophy",
        "myotonic dystrophy",
        "autosomal recessive limb-girdle muscular dystrophy",
        "congenital muscular dystrophy with intellectual disability",
        "autosomal recessive limb-girdle muscular dystrophy type 2E",
        "Bethlem myopathy 1C",
        "Emery-Dreifuss muscular dystrophy 1, X-linked",
        "epidermolysis bullosa simplex 5B, with muscular dystrophy",
        "Miyoshi muscular dystrophy 3",
        "muscular dystrophy-dystroglycanopathy type B5",
        "congenital myopathy 7A, myosin storage, autosomal dominant",
        "autosomal recessive limb-girdle muscular dystrophy type 2O",
        "nebulin-related early-onset distal myopathy",
        "autosomal dominant limb-girdle muscular dystrophy type 1F",
        "congenital-onset Steinert myotonic dystrophy",
        "oculopharyngeal muscular dystrophy",
        "Bethlem myopathy",
        "facioscapulohumeral muscular dystrophy",
        "congenital muscular dystrophy due to integrin alpha-7 deficiency",
        "myopathy, distal, 7, adult-onset, X-linked",
        "fibrosis of extraocular muscles, congenital, 2",
        "autosomal recessive limb-girdle muscular dystrophy type 2Y",
        "muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B14",
        "facioscapulohumeral muscular dystrophy 3, digenic",
        "Bethlem myopathy 2",
        "collagen 6-related congenital muscular dystrophy",
        "Ullrich congenital muscular dystrophy 1A",
        "muscular dystrophy-dystroglycanopathy (limb-girdle), type C, 8",
        "Emery-Dreifuss muscular dystrophy 4, autosomal dominant",
        "myopathy, distal, infantile-onset",
        "oculopharyngeal muscular dystrophy 2",
        "autosomal recessive limb-girdle muscular dystrophy type 2F",
        "Ullrich congenital muscular dystrophy 1B",
        "autosomal recessive limb-girdle muscular dystrophy type 2G",
        "adult-onset distal myopathy due to VCP mutation",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A3",
        "Duchenne muscular dystrophy",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 12",
        "muscular dystrophy, limb-girdle, autosomal recessive 26",
        "oculopharyngeal muscular dystrophy 1",
        "autosomal recessive limb-girdle muscular dystrophy type R18",
        "Fukuda-Miyanomae-Nakata syndrome",
        "distal myopathy, Welander type",
        "autosomal dominant limb-girdle muscular dystrophy type 1E (DES)",
        "myopathy, distal, 5",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A, 7",
        "late-onset Steinert myotonic dystrophy",
        "myotonic dystrophy type 1",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A1",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A5",
        "Emery-Dreifuss muscular dystrophy 3, autosomal recessive",
        "Emery-Dreifuss muscular dystrophy",
        "asymptomatic hyperckemia-myalgia-rhabdomyolysis syndrome",
        "MYH7-related skeletal myopathy",
        "congenital muscular dystrophy caused by variation in POMGNT2",
        "Emery-Dreifuss muscular dystrophy 6, X-linked",
        "progressive scapulohumeroperoneal distal myopathy",
        "distal myopathy with anterior tibial onset",
        "autosomal recessive limb-girdle muscular dystrophy type 2U",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A2",
        "arthrogryposis due to muscular dystrophy",
        "autosomal dominant Emery-Dreifuss muscular dystrophy",
        "POMGNT2-related limb-girdle muscular dystrophy R24",
        "KLHL9-related early-onset distal myopathy",
        "congenital muscular dystrophy with intellectual disability and severe epilepsy",
        "autosomal recessive limb-girdle muscular dystrophy type 2M",
        "myofibrillar myopathy 2",
        "fibrosis of extraocular muscles, congenital, 3A, with or without extraocular involvement",
        "Miyoshi muscular dystrophy 2",
        "congenital merosin-deficient muscular dystrophy 1A",
        "congenital fibrosis of extraocular muscles type 1",
        "rigid spine syndrome",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 10",
        "autosomal recessive limb-girdle muscular dystrophy type 2Q",
        "congenital muscular dystrophy 1B",
        "autosomal recessive limb-girdle muscular dystrophy type 2R1",
        "muscular dystrophy-dystroglycanopathy (congenital without intellectual disability), type B4",
        "Ullrich congenital muscular dystrophy",
        "fibrosis of extraocular muscles, congenital, with synergistic divergence",
        "Emery-Dreifuss muscular dystrophy 5, autosomal dominant",
        "Emery-Dreifuss muscular dystrophy 7, autosomal dominant",
        "symptomatic form of muscular dystrophy of Duchenne and Becker in female carriers",
        "muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A13",
        "myotonic cataract",
        "muscular dystrophy, cardiac type",
        "SNUPN-related muscular dystrophy with or without multi-system involvement",
        "progressive muscular dystrophy",
        "myopathy, autophagic vacuolar, infantile-onset",
        "distal myopathy, Tateyama type",
        "oculopharyngodistal myopathy 1",
        "oculopharyngodistal myopathy 2",
        "myopathy, distal, with rimmed vacuoles",
        "desmin-related myopathy with Mallory body-like inclusions",
        "fibrosis of extraocular muscles, congenital, 3b"
    ],
    "has_descendant_count": 197,
    "inheritance": null,
    "causal_gene": [],
    "causes_disease": null,
    "mappings": [
        {
            "id": "Orphanet:98473",
            "url": "https://www.orpha.net/en/disease/detail/98473"
        },
        {
            "id": "icd11.foundation:1464662404",
            "url": null
        },
        {
            "id": "MEDGEN:44527",
            "url": "http://identifiers.org/medgen/44527"
        },
        {
            "id": "DOID:9884",
            "url": "http://purl.obolibrary.org/obo/DOID_9884"
        },
        {
            "id": "MESH:D009136",
            "url": "http://identifiers.org/mesh/D009136"
        },
        {
            "id": "NCIT:C84910",
            "url": "http://purl.obolibrary.org/obo/NCIT_C84910"
        },
        {
            "id": "SCTID:73297009",
            "url": "http://identifiers.org/snomedct/73297009"
        },
        {
            "id": "UMLS:C0026850",
            "url": "http://identifiers.org/umls/C0026850"
        },
        {
            "id": "ICD10CM:G71.0",
            "url": "https://icd.codes/icd10cm/G71.0"
        }
    ],
    "external_links": [
        {
            "id": "DOID:9884",
            "url": "http://purl.obolibrary.org/obo/DOID_9884"
        },
        {
            "id": "GARD:7922",
            "url": "https://rarediseases.info.nih.gov/diseases/7922/index"
        },
        {
            "id": "ICD10CM:G71.0",
            "url": "https://icd.codes/icd10cm/G71.0"
        },
        {
            "id": "ICD9:359.1",
            "url": null
        },
        {
            "id": "MEDGEN:44527",
            "url": "http://identifiers.org/medgen/44527"
        },
        {
            "id": "MESH:D009136",
            "url": "http://identifiers.org/mesh/D009136"
        },
        {
            "id": "MedDRA:10028356",
            "url": null
        },
        {
            "id": "NANDO:1200486",
            "url": "http://identifiers.org/NANDO/1200486"
        },
        {
            "id": "NANDO:2100233",
            "url": "http://identifiers.org/NANDO/2100233"
        },
        {
            "id": "NCIT:C84910",
            "url": "http://purl.obolibrary.org/obo/NCIT_C84910"
        },
        {
            "id": "Orphanet:98473",
            "url": "https://www.orpha.net/en/disease/detail/98473"
        },
        {
            "id": "SCTID:73297009",
            "url": "http://identifiers.org/snomedct/73297009"
        },
        {
            "id": "UMLS:C0026850",
            "url": "http://identifiers.org/umls/C0026850"
        },
        {
            "id": "icd11.foundation:1464662404",
            "url": null
        }
    ],
    "provided_by_link": {
        "id": "phenio",
        "url": "https://monarch-initiative.github.io/monarch-ingest/Sources/phenio/#"
    },
    "association_counts": [
        {
            "label": "Disease to Phenotype",
            "count": 4161,
            "category": "biolink:DiseaseToPhenotypicFeatureAssociation"
        },
        {
            "label": "Causal Gene",
            "count": 130,
            "category": "biolink:CausalGeneToDiseaseAssociation"
        },
        {
            "label": "Correlated Gene",
            "count": 150,
            "category": "biolink:CorrelatedGeneToDiseaseAssociation"
        },
        {
            "label": "Variant to Disease",
            "count": 435,
            "category": "biolink:VariantToDiseaseAssociation"
        },
        {
            "label": "Disease Model",
            "count": 244,
            "category": "biolink:GenotypeToDiseaseAssociation"
        },
        {
            "label": "Medical Action",
            "count": 4,
            "category": "biolink:ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation"
        },
        {
            "label": "Cases",
            "count": 136,
            "category": "biolink:CaseToDiseaseAssociation"
        }
    ],
    "node_hierarchy": {
        "super_classes": [
            {
                "id": "MONDO:0005336",
                "category": "biolink:Disease",
                "name": "myopathy",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0100546",
                "category": "biolink:Disease",
                "name": "hereditary neuromuscular disease",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0700223",
                "category": "biolink:Disease",
                "name": "hereditary skeletal muscle disorder",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            }
        ],
        "sub_classes": [
            {
                "id": "MONDO:0008028",
                "category": "biolink:Disease",
                "name": "muscular dystrophy, Barnes type",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0010675",
                "category": "biolink:Disease",
                "name": "muscular dystrophy, cardiac type",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0010676",
                "category": "biolink:Disease",
                "name": "muscular dystrophy, Hemizygous lethal type",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0010677",
                "category": "biolink:Disease",
                "name": "muscular dystrophy, Mabry type",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0010678",
                "category": "biolink:Disease",
                "name": "muscular dystrophy, progressive Pectorodorsal",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0016106",
                "category": "biolink:Disease",
                "name": "progressive muscular dystrophy",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0019950",
                "category": "biolink:Disease",
                "name": "congenital muscular dystrophy",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0018949",
                "category": "biolink:Disease",
                "name": "distal myopathy",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0023204",
                "category": "biolink:Disease",
                "name": "Fukuda-Miyanomae-Nakata syndrome",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0100228",
                "category": "biolink:Disease",
                "name": "LAMA2-related muscular dystrophy",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            },
            {
                "id": "MONDO:0700285",
                "category": "biolink:Disease",
                "name": "DMD-related muscular dystrophy",
                "full_name": null,
                "deprecated": null,
                "description": null,
                "xref": null,
                "provided_by": null,
                "in_taxon": null,
                "in_taxon_label": null,
                "symbol": null,
                "synonym": null,
                "broad_synonym": null,
                "exact_synonym": null,
                "narrow_synonym": null,
                "related_synonym": null,
                "subsets": null,
                "uri": null,
                "iri": null,
                "namespace": null,
                "has_phenotype": null,
                "has_phenotype_label": null,
                "has_phenotype_closure": null,
                "has_phenotype_closure_label": null,
                "has_phenotype_count": null,
                "has_descendant": null,
                "has_descendant_label": null,
                "has_descendant_count": null
            }
        ]
    },
    "file_source": [
        "phenio_nodes"
    ]
}
"""

@pytest.fixture
def node_tsv():
    return """
id	category	name	full_name	deprecated	description	xref	provided_by	in_taxon	in_taxon_label	symbol	synonym	broad_synonym	exact_synonym	narrow_synonym	related_synonym	subsets	uri	iri	namespace	has_phenotype	has_phenotype_label	has_phenotype_closure	has_phenotype_closure_label	has_phenotype_count	has_descendant	has_descendant_label	has_descendant_count	inheritance	causal_gene	causes_disease	mappings	external_links	provided_by_link	association_counts	node_hierarchy	file_source
MONDO:0020121	biolink:Disease	muscular dystrophy	None	None	Muscular dystrophy (MD) refers to a group of more than 30 genetic diseases characterized by progressive weakness and degeneration of the skeletal muscles that control movement. Some forms of MD are seen in newborns, infants or children, while others have late-onset and may not appear until middle age or later. The disorders differ in terms of the distribution and extent of muscle weakness (some forms of MD also affect cardiac muscle), age of onset, rate of progression, and pattern of inheritance. The prognosis for people with MD varies according to the type and progression of the disorder. There is no specific treatment to stop or reverse any form of MD. Treatment is supportive and may include physical therapy, respiratory therapy, speech therapy, orthopedic appliances used for support, corrective orthopedic surgery, and medicationsincluding corticosteroids, anticonvulsants (seizure medications), immunosuppressants, and antibiotics. Some individuals may need assisted ventilation to treat respiratory muscle weaknessor a pacemaker for cardiac (heart)abnormalities.	['DOID:9884', 'GARD:7922', 'ICD10CM:G71.0', 'ICD9:359.1', 'MEDGEN:44527', 'MESH:D009136', 'MedDRA:10028356', 'NANDO:1200486', 'NANDO:2100233', 'NCIT:C84910', 'Orphanet:98473', 'SCTID:73297009', 'UMLS:C0026850', 'icd11.foundation:1464662404']	phenio_nodes	None	None	None	None	None	None	None	None	['disease_grouping|gard_rare|ordo_group_of_disorders|otar|rare']	http://purl.obolibrary.org/obo/MONDO_0020121	None	MONDO	None	None	None	None	0	['MONDO:0013162', 'MONDO:0971171', 'MONDO:0018951', 'MONDO:0035648', 'MONDO:0010678', 'MONDO:0011787', 'MONDO:0013158', 'MONDO:0019950', 'MONDO:0013159', 'MONDO:0011968', 'MONDO:0010400', 'MONDO:0012277', 'MONDO:0000727', 'MONDO:0012215', 'MONDO:0016108', 'MONDO:0000173', 'MONDO:0024530', 'MONDO:0009675', 'MONDO:0024607', 'MONDO:0017892', 'MONDO:0007614', 'MONDO:0014071', 'MONDO:0013049', 'MONDO:0030456', 'MONDO:0023671', 'MONDO:0029133', 'MONDO:0018281', 'MONDO:0021569', 'MONDO:0015151', 'MONDO:0030712', 'MONDO:0018939', 'MONDO:1040033', 'MONDO:0009683', 'MONDO:0011246', 'MONDO:0014788', 'MONDO:0013155', 'MONDO:0010676', 'MONDO:0009690', 'MONDO:0700285', 'MONDO:0033556', 'MONDO:0035649', 'MONDO:0014683', 'MONDO:0009678', 'MONDO:0010311', 'MONDO:0958233', 'MONDO:0010870', 'MONDO:0000172', 'MONDO:0013297', 'MONDO:0010884', 'MONDO:0023595', 'MONDO:0009677', 'MONDO:0035647', 'MONDO:0010401', 'MONDO:0010677', 'MONDO:0014782', 'MONDO:0008030', 'MONDO:0014140', 'MONDO:0021018', 'MONDO:0018759', 'MONDO:0011266', 'MONDO:0008034', 'MONDO:0100228', 'MONDO:0012193', 'MONDO:0014489', 'MONDO:0029136', 'MONDO:0013550', 'MONDO:0012248', 'MONDO:0012652', 'MONDO:0013904', 'MONDO:0009676', 'MONDO:0012410', 'MONDO:0013160', 'MONDO:0957270', 'MONDO:0014896', 'MONDO:0012138', 'MONDO:0013178', 'MONDO:0025193', 'MONDO:0010684', 'MONDO:0008028', 'MONDO:0014654', 'MONDO:0024545', 'MONDO:0030355', 'MONDO:0012127', 'MONDO:0010680', 'MONDO:0009682', 'MONDO:0018949', 'MONDO:0011271', 'MONDO:0009685', 'MONDO:0009680', 'MONDO:0016049', 'MONDO:0000171', 'MONDO:0013440', 'MONDO:0018280', 'MONDO:0012262', 'MONDO:0958236', 'MONDO:0012270', 'MONDO:0014142', 'MONDO:0020121', 'MONDO:0016971', 'MONDO:0018276', 'MONDO:0008031', 'MONDO:0011362', 'MONDO:0014538', 'MONDO:0958353', 'MONDO:0016107', 'MONDO:0015152', 'MONDO:0018278', 'MONDO:0011423', 'MONDO:0958234', 'MONDO:0100531', 'MONDO:0009181', 'MONDO:0013222', 'MONDO:0011688', 'MONDO:0008409', 'MONDO:0013161', 'MONDO:0018371', 'MONDO:0012034', 'MONDO:0035646', 'MONDO:0008116', 'MONDO:0008029', 'MONDO:0001347', 'MONDO:0013177', 'MONDO:0024771', 'MONDO:0011181', 'MONDO:0014900', 'MONDO:0014141', 'MONDO:0030354', 'MONDO:0034022', 'MONDO:0958077', 'MONDO:0009681', 'MONDO:0029135', 'MONDO:0013071', 'MONDO:0008049', 'MONDO:0958195', 'MONDO:0011028', 'MONDO:0958235', 'MONDO:0011170', 'MONDO:0018006', 'MONDO:0009667', 'MONDO:0010679', 'MONDO:0014101', 'MONDO:0030014', 'MONDO:0958176', 'MONDO:0014144', 'MONDO:0023204', 'MONDO:0011466', 'MONDO:0018098', 'MONDO:0014877', 'MONDO:0013835', 'MONDO:0035650', 'MONDO:0008056', 'MONDO:0009364', 'MONDO:0013157', 'MONDO:0014676', 'MONDO:0016830', 'MONDO:0975918', 'MONDO:0008050', 'MONDO:0700075', 'MONDO:0800318', 'MONDO:0014800', 'MONDO:0011721', 'MONDO:0014474', 'MONDO:0013154', 'MONDO:0009679', 'MONDO:0020336', 'MONDO:0035432', 'MONDO:0018370', 'MONDO:0014023', 'MONDO:0012699', 'MONDO:0012130', 'MONDO:0010912', 'MONDO:0013221', 'MONDO:0011925', 'MONDO:0021083', 'MONDO:0019951', 'MONDO:0014022', 'MONDO:0013390', 'MONDO:0011486', 'MONDO:0014977', 'MONDO:0013156', 'MONDO:0000355', 'MONDO:0012310', 'MONDO:0013072', 'MONDO:0013677', 'MONDO:0016097', 'MONDO:0014120', 'MONDO:0004495', 'MONDO:0010675', 'MONDO:0100584', 'MONDO:0016106', 'MONDO:0012286', 'MONDO:0013686', 'MONDO:0020793', 'MONDO:0030134', 'MONDO:0014945', 'MONDO:0019398', 'MONDO:0800209']	['autosomal recessive limb-girdle muscular dystrophy type 2N', 'muscular dystrophy, limb-girdle, autosomal recessive 29', 'distal myopathy with vocal cord weakness', 'juvenile-onset Steinert myotonic dystrophy', 'muscular dystrophy, progressive Pectorodorsal', 'autosomal recessive limb-girdle muscular dystrophy type 2I', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A6', 'congenital muscular dystrophy', 'muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B1', 'autosomal recessive limb-girdle muscular dystrophy type 2D', 'X-linked scapuloperoneal muscular dystrophy', 'myofibrillar myopathy 4', 'scapuloperoneal myopathy', 'myofibrillar myopathy 3', 'autosomal dominant distal myopathy', 'muscular dystrophy-dystroglycanopathy, type C', 'Bethlem myopathy 1A', 'autosomal recessive limb-girdle muscular dystrophy type 2A', 'congenital muscular dystrophy with cataracts and intellectual disability', 'autosomal recessive myogenic arthrogryposis multiplex congenita', 'congenital fibrosis of extraocular muscles', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 11', 'DPM3-congenital disorder of glycosylation', 'muscular dystrophy, limb-girdle, autosomal recessive 27', 'oculopharyngodistal myopathy 3', 'muscular dystrophy, limb-girdle, autosomal dominant 4', 'congenital muscular dystrophy with hyperlaxity', 'Emery-Dreifuss muscular dystrophy 2, autosomal dominant', 'muscular dystrophy, limb-girdle, autosomal dominant', 'oculopharyngodistal myopathy 4', 'muscle-eye-brain disease', 'congenital muscular dystrophy without intellectual disability', 'autosomal recessive limb-girdle muscular dystrophy type 2H', 'megaconial type congenital muscular dystrophy', 'autosomal recessive limb-girdle muscular dystrophy type 2W', 'muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B3', 'muscular dystrophy, Hemizygous lethal type', 'congenital myasthenic syndrome 10', 'DMD-related muscular dystrophy', 'muscular dystrophy-dystroglycanopathy (congenital with impaired intellectual development), type B, 15', 'adult-onset Steinert myotonic dystrophy', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A9', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A, 4', 'Becker muscular dystrophy', 'Bethlem myopathy 1B', 'tibial muscular dystrophy', 'muscular dystrophy-dystroglycanopathy, type B', 'autosomal dominant limb-girdle muscular dystrophy type 1H', 'muscular dystrophy, scapulohumeral', 'congenital myotonic dystrophy', 'autosomal recessive limb-girdle muscular dystrophy type 2C', 'childhood-onset Steinert myotonic dystrophy', 'X-linked myopathy with postural muscle atrophy', 'muscular dystrophy, Mabry type', 'autosomal recessive limb-girdle muscular dystrophy type 2X', 'facioscapulohumeral muscular dystrophy 1', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A14', 'autosomal dominant limb-girdle muscular dystrophy type 1D (DNAJB6)', 'childhood-onset progressive contractures-limb-girdle weakness-muscle dystrophy syndrome', 'myotonic dystrophy type 2', 'muscular dystrophy, pseudohypertrophic, with Internalized capillaries', 'LAMA2-related muscular dystrophy', 'autosomal dominant limb-girdle muscular dystrophy type 1G', 'limb-girdle muscular dystrophy due to POMK deficiency', 'muscular dystrophy, limb-girdle, autosomal recessive 23', 'distal myopathy with posterior leg and anterior hand involvement', 'autosomal recessive limb-girdle muscular dystrophy type 2K', 'autosomal recessive limb-girdle muscular dystrophy type 2L', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 8', 'autosomal recessive limb-girdle muscular dystrophy type 2B', 'Finnish upper limb-onset distal myopathy', 'muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B2', 'muscular dystrophy, limb-girdle, autosomal recessive 28', 'congenital muscular dystrophy-respiratory failure-skin abnormalities-joint hyperlaxity syndrome', 'muscular dystrophy-dystroglycanopathy type B6', 'congenital muscular dystrophy due to LMNA mutation', 'oculopharyngodistal myopathy', 'X-linked myopathy with excessive autophagy', 'muscular dystrophy, Barnes type', 'Ullrich congenital muscular dystrophy 2', 'Miyoshi muscular dystrophy 1', 'facioscapulohumeral muscular dystrophy 4, digenic', 'autosomal recessive limb-girdle muscular dystrophy type 2J', 'X-linked Emery-Dreifuss muscular dystrophy', 'muscular dystrophy, congenital, with rapid progression', 'distal myopathy', 'rigid spine muscular dystrophy 1', 'Miyoshi myopathy', 'congenital muscular dystrophy-infantile cataract-hypogonadism syndrome', 'congenital myopathy, Paradas type', 'muscular dystrophy-dystroglycanopathy, type A', 'autosomal recessive limb-girdle muscular dystrophy type 2P', 'muscle-eye-brain disease with bilateral multicystic leucodystrophy', 'fibrosis of extraocular muscles, congenital, 3c', 'Ullrich congenital muscular dystrophy 1C', 'Tukel syndrome', 'autosomal recessive limb-girdle muscular dystrophy type 2T', 'muscular dystrophy', 'limb-girdle muscular dystrophy', 'muscular dystrophy-dystroglycanopathy', 'facioscapulohumeral muscular dystrophy 2', 'myopathy, myofibrillar, 9, with early respiratory failure', 'fibrosis of extraocular muscles, congenital, 5', 'intermediate collagen VI-related muscular dystrophy', 'myotonic dystrophy', 'autosomal recessive limb-girdle muscular dystrophy', 'congenital muscular dystrophy with intellectual disability', 'autosomal recessive limb-girdle muscular dystrophy type 2E', 'Bethlem myopathy 1C', 'Emery-Dreifuss muscular dystrophy 1, X-linked', 'epidermolysis bullosa simplex 5B, with muscular dystrophy', 'Miyoshi muscular dystrophy 3', 'muscular dystrophy-dystroglycanopathy type B5', 'congenital myopathy 7A, myosin storage, autosomal dominant', 'autosomal recessive limb-girdle muscular dystrophy type 2O', 'nebulin-related early-onset distal myopathy', 'autosomal dominant limb-girdle muscular dystrophy type 1F', 'congenital-onset Steinert myotonic dystrophy', 'oculopharyngeal muscular dystrophy', 'Bethlem myopathy', 'facioscapulohumeral muscular dystrophy', 'congenital muscular dystrophy due to integrin alpha-7 deficiency', 'myopathy, distal, 7, adult-onset, X-linked', 'fibrosis of extraocular muscles, congenital, 2', 'autosomal recessive limb-girdle muscular dystrophy type 2Y', 'muscular dystrophy-dystroglycanopathy (congenital with intellectual disability), type B14', 'facioscapulohumeral muscular dystrophy 3, digenic', 'Bethlem myopathy 2', 'collagen 6-related congenital muscular dystrophy', 'Ullrich congenital muscular dystrophy 1A', 'muscular dystrophy-dystroglycanopathy (limb-girdle), type C, 8', 'Emery-Dreifuss muscular dystrophy 4, autosomal dominant', 'myopathy, distal, infantile-onset', 'oculopharyngeal muscular dystrophy 2', 'autosomal recessive limb-girdle muscular dystrophy type 2F', 'Ullrich congenital muscular dystrophy 1B', 'autosomal recessive limb-girdle muscular dystrophy type 2G', 'adult-onset distal myopathy due to VCP mutation', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A3', 'Duchenne muscular dystrophy', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 12', 'muscular dystrophy, limb-girdle, autosomal recessive 26', 'oculopharyngeal muscular dystrophy 1', 'autosomal recessive limb-girdle muscular dystrophy type R18', 'Fukuda-Miyanomae-Nakata syndrome', 'distal myopathy, Welander type', 'autosomal dominant limb-girdle muscular dystrophy type 1E (DES)', 'myopathy, distal, 5', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A, 7', 'late-onset Steinert myotonic dystrophy', 'myotonic dystrophy type 1', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A1', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A5', 'Emery-Dreifuss muscular dystrophy 3, autosomal recessive', 'Emery-Dreifuss muscular dystrophy', 'asymptomatic hyperckemia-myalgia-rhabdomyolysis syndrome', 'MYH7-related skeletal myopathy', 'congenital muscular dystrophy caused by variation in POMGNT2', 'Emery-Dreifuss muscular dystrophy 6, X-linked', 'progressive scapulohumeroperoneal distal myopathy', 'distal myopathy with anterior tibial onset', 'autosomal recessive limb-girdle muscular dystrophy type 2U', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A2', 'arthrogryposis due to muscular dystrophy', 'autosomal dominant Emery-Dreifuss muscular dystrophy', 'POMGNT2-related limb-girdle muscular dystrophy R24', 'KLHL9-related early-onset distal myopathy', 'congenital muscular dystrophy with intellectual disability and severe epilepsy', 'autosomal recessive limb-girdle muscular dystrophy type 2M', 'myofibrillar myopathy 2', 'fibrosis of extraocular muscles, congenital, 3A, with or without extraocular involvement', 'Miyoshi muscular dystrophy 2', 'congenital merosin-deficient muscular dystrophy 1A', 'congenital fibrosis of extraocular muscles type 1', 'rigid spine syndrome', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type a, 10', 'autosomal recessive limb-girdle muscular dystrophy type 2Q', 'congenital muscular dystrophy 1B', 'autosomal recessive limb-girdle muscular dystrophy type 2R1', 'muscular dystrophy-dystroglycanopathy (congenital without intellectual disability), type B4', 'Ullrich congenital muscular dystrophy', 'fibrosis of extraocular muscles, congenital, with synergistic divergence', 'Emery-Dreifuss muscular dystrophy 5, autosomal dominant', 'Emery-Dreifuss muscular dystrophy 7, autosomal dominant', 'symptomatic form of muscular dystrophy of Duchenne and Becker in female carriers', 'muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies), type A13', 'myotonic cataract', 'muscular dystrophy, cardiac type', 'SNUPN-related muscular dystrophy with or without multi-system involvement', 'progressive muscular dystrophy', 'myopathy, autophagic vacuolar, infantile-onset', 'distal myopathy, Tateyama type', 'oculopharyngodistal myopathy 1', 'oculopharyngodistal myopathy 2', 'myopathy, distal, with rimmed vacuoles', 'desmin-related myopathy with Mallory body-like inclusions', 'fibrosis of extraocular muscles, congenital, 3b']	197	None	[]	None	[{'id': 'Orphanet:98473', 'url': 'https://www.orpha.net/en/disease/detail/98473'}, {'id': 'icd11.foundation:1464662404', 'url': None}, {'id': 'MEDGEN:44527', 'url': 'http://identifiers.org/medgen/44527'}, {'id': 'DOID:9884', 'url': 'http://purl.obolibrary.org/obo/DOID_9884'}, {'id': 'MESH:D009136', 'url': 'http://identifiers.org/mesh/D009136'}, {'id': 'NCIT:C84910', 'url': 'http://purl.obolibrary.org/obo/NCIT_C84910'}, {'id': 'SCTID:73297009', 'url': 'http://identifiers.org/snomedct/73297009'}, {'id': 'UMLS:C0026850', 'url': 'http://identifiers.org/umls/C0026850'}, {'id': 'ICD10CM:G71.0', 'url': 'https://icd.codes/icd10cm/G71.0'}]	[{'id': 'DOID:9884', 'url': 'http://purl.obolibrary.org/obo/DOID_9884'}, {'id': 'GARD:7922', 'url': 'https://rarediseases.info.nih.gov/diseases/7922/index'}, {'id': 'ICD10CM:G71.0', 'url': 'https://icd.codes/icd10cm/G71.0'}, {'id': 'ICD9:359.1', 'url': None}, {'id': 'MEDGEN:44527', 'url': 'http://identifiers.org/medgen/44527'}, {'id': 'MESH:D009136', 'url': 'http://identifiers.org/mesh/D009136'}, {'id': 'MedDRA:10028356', 'url': None}, {'id': 'NANDO:1200486', 'url': 'http://identifiers.org/NANDO/1200486'}, {'id': 'NANDO:2100233', 'url': 'http://identifiers.org/NANDO/2100233'}, {'id': 'NCIT:C84910', 'url': 'http://purl.obolibrary.org/obo/NCIT_C84910'}, {'id': 'Orphanet:98473', 'url': 'https://www.orpha.net/en/disease/detail/98473'}, {'id': 'SCTID:73297009', 'url': 'http://identifiers.org/snomedct/73297009'}, {'id': 'UMLS:C0026850', 'url': 'http://identifiers.org/umls/C0026850'}, {'id': 'icd11.foundation:1464662404', 'url': None}]	{'id': 'phenio', 'url': 'https://monarch-initiative.github.io/monarch-ingest/Sources/phenio/#'}	[{'label': 'Disease to Phenotype', 'count': 4161, 'category': 'biolink:DiseaseToPhenotypicFeatureAssociation'}, {'label': 'Causal Gene', 'count': 130, 'category': 'biolink:CausalGeneToDiseaseAssociation'}, {'label': 'Correlated Gene', 'count': 150, 'category': 'biolink:CorrelatedGeneToDiseaseAssociation'}, {'label': 'Variant to Disease', 'count': 435, 'category': 'biolink:VariantToDiseaseAssociation'}, {'label': 'Disease Model', 'count': 244, 'category': 'biolink:GenotypeToDiseaseAssociation'}, {'label': 'Medical Action', 'count': 4, 'category': 'biolink:ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation'}, {'label': 'Cases', 'count': 136, 'category': 'biolink:CaseToDiseaseAssociation'}]	{'super_classes': [{'id': 'MONDO:0005336', 'category': 'biolink:Disease', 'name': 'myopathy', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0100546', 'category': 'biolink:Disease', 'name': 'hereditary neuromuscular disease', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0700223', 'category': 'biolink:Disease', 'name': 'hereditary skeletal muscle disorder', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}], 'sub_classes': [{'id': 'MONDO:0008028', 'category': 'biolink:Disease', 'name': 'muscular dystrophy, Barnes type', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0010675', 'category': 'biolink:Disease', 'name': 'muscular dystrophy, cardiac type', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0010676', 'category': 'biolink:Disease', 'name': 'muscular dystrophy, Hemizygous lethal type', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0010677', 'category': 'biolink:Disease', 'name': 'muscular dystrophy, Mabry type', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0010678', 'category': 'biolink:Disease', 'name': 'muscular dystrophy, progressive Pectorodorsal', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0016106', 'category': 'biolink:Disease', 'name': 'progressive muscular dystrophy', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0019950', 'category': 'biolink:Disease', 'name': 'congenital muscular dystrophy', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0018949', 'category': 'biolink:Disease', 'name': 'distal myopathy', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0023204', 'category': 'biolink:Disease', 'name': 'Fukuda-Miyanomae-Nakata syndrome', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0100228', 'category': 'biolink:Disease', 'name': 'LAMA2-related muscular dystrophy', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}, {'id': 'MONDO:0700285', 'category': 'biolink:Disease', 'name': 'DMD-related muscular dystrophy', 'full_name': None, 'deprecated': None, 'description': None, 'xref': None, 'provided_by': None, 'in_taxon': None, 'in_taxon_label': None, 'symbol': None, 'synonym': None, 'broad_synonym': None, 'exact_synonym': None, 'narrow_synonym': None, 'related_synonym': None, 'subsets': None, 'uri': None, 'iri': None, 'namespace': None, 'has_phenotype': None, 'has_phenotype_label': None, 'has_phenotype_closure': None, 'has_phenotype_closure_label': None, 'has_phenotype_count': None, 'has_descendant': None, 'has_descendant_label': None, 'has_descendant_count': None}]}	['phenio_nodes']
"""

@pytest.fixture
def node_yaml():
    return """
association_counts:
- category: biolink:DiseaseToPhenotypicFeatureAssociation
  count: 4161
  label: Disease to Phenotype
- category: biolink:CausalGeneToDiseaseAssociation
  count: 130
  label: Causal Gene
- category: biolink:CorrelatedGeneToDiseaseAssociation
  count: 150
  label: Correlated Gene
- category: biolink:VariantToDiseaseAssociation
  count: 435
  label: Variant to Disease
- category: biolink:GenotypeToDiseaseAssociation
  count: 244
  label: Disease Model
- category: biolink:ChemicalOrDrugOrTreatmentToDiseaseOrPhenotypicFeatureAssociation
  count: 4
  label: Medical Action
- category: biolink:CaseToDiseaseAssociation
  count: 136
  label: Cases
broad_synonym: null
category: biolink:Disease
causal_gene: []
causes_disease: null
deprecated: null
description: Muscular dystrophy (MD) refers to a group of more than 30 genetic diseases
  characterized by progressive weakness and degeneration of the skeletal muscles that
  control movement. Some forms of MD are seen in newborns, infants or children, while
  others have late-onset and may not appear until middle age or later. The disorders
  differ in terms of the distribution and extent of muscle weakness (some forms of
  MD also affect cardiac muscle), age of onset, rate of progression, and pattern of
  inheritance. The prognosis for people with MD varies according to the type and progression
  of the disorder. There is no specific treatment to stop or reverse any form of MD.
  Treatment is supportive and may include physical therapy, respiratory therapy, speech
  therapy, orthopedic appliances used for support, corrective orthopedic surgery,
  and medicationsincluding corticosteroids, anticonvulsants (seizure medications),
  immunosuppressants, and antibiotics. Some individuals may need assisted ventilation
  to treat respiratory muscle weaknessor a pacemaker for cardiac (heart)abnormalities.
exact_synonym: null
external_links:
- id: DOID:9884
  url: http://purl.obolibrary.org/obo/DOID_9884
- id: GARD:7922
  url: https://rarediseases.info.nih.gov/diseases/7922/index
- id: ICD10CM:G71.0
  url: https://icd.codes/icd10cm/G71.0
- id: ICD9:359.1
  url: null
- id: MEDGEN:44527
  url: http://identifiers.org/medgen/44527
- id: MESH:D009136
  url: http://identifiers.org/mesh/D009136
- id: MedDRA:10028356
  url: null
- id: NANDO:1200486
  url: http://identifiers.org/NANDO/1200486
- id: NANDO:2100233
  url: http://identifiers.org/NANDO/2100233
- id: NCIT:C84910
  url: http://purl.obolibrary.org/obo/NCIT_C84910
- id: Orphanet:98473
  url: https://www.orpha.net/en/disease/detail/98473
- id: SCTID:73297009
  url: http://identifiers.org/snomedct/73297009
- id: UMLS:C0026850
  url: http://identifiers.org/umls/C0026850
- id: icd11.foundation:1464662404
  url: null
file_source:
- phenio_nodes
full_name: null
has_descendant:
- MONDO:0013162
- MONDO:0971171
- MONDO:0018951
- MONDO:0035648
- MONDO:0010678
- MONDO:0011787
- MONDO:0013158
- MONDO:0019950
- MONDO:0013159
- MONDO:0011968
- MONDO:0010400
- MONDO:0012277
- MONDO:0000727
- MONDO:0012215
- MONDO:0016108
- MONDO:0000173
- MONDO:0024530
- MONDO:0009675
- MONDO:0024607
- MONDO:0017892
- MONDO:0007614
- MONDO:0014071
- MONDO:0013049
- MONDO:0030456
- MONDO:0023671
- MONDO:0029133
- MONDO:0018281
- MONDO:0021569
- MONDO:0015151
- MONDO:0030712
- MONDO:0018939
- MONDO:1040033
- MONDO:0009683
- MONDO:0011246
- MONDO:0014788
- MONDO:0013155
- MONDO:0010676
- MONDO:0009690
- MONDO:0700285
- MONDO:0033556
- MONDO:0035649
- MONDO:0014683
- MONDO:0009678
- MONDO:0010311
- MONDO:0958233
- MONDO:0010870
- MONDO:0000172
- MONDO:0013297
- MONDO:0010884
- MONDO:0023595
- MONDO:0009677
- MONDO:0035647
- MONDO:0010401
- MONDO:0010677
- MONDO:0014782
- MONDO:0008030
- MONDO:0014140
- MONDO:0021018
- MONDO:0018759
- MONDO:0011266
- MONDO:0008034
- MONDO:0100228
- MONDO:0012193
- MONDO:0014489
- MONDO:0029136
- MONDO:0013550
- MONDO:0012248
- MONDO:0012652
- MONDO:0013904
- MONDO:0009676
- MONDO:0012410
- MONDO:0013160
- MONDO:0957270
- MONDO:0014896
- MONDO:0012138
- MONDO:0013178
- MONDO:0025193
- MONDO:0010684
- MONDO:0008028
- MONDO:0014654
- MONDO:0024545
- MONDO:0030355
- MONDO:0012127
- MONDO:0010680
- MONDO:0009682
- MONDO:0018949
- MONDO:0011271
- MONDO:0009685
- MONDO:0009680
- MONDO:0016049
- MONDO:0000171
- MONDO:0013440
- MONDO:0018280
- MONDO:0012262
- MONDO:0958236
- MONDO:0012270
- MONDO:0014142
- MONDO:0020121
- MONDO:0016971
- MONDO:0018276
- MONDO:0008031
- MONDO:0011362
- MONDO:0014538
- MONDO:0958353
- MONDO:0016107
- MONDO:0015152
- MONDO:0018278
- MONDO:0011423
- MONDO:0958234
- MONDO:0100531
- MONDO:0009181
- MONDO:0013222
- MONDO:0011688
- MONDO:0008409
- MONDO:0013161
- MONDO:0018371
- MONDO:0012034
- MONDO:0035646
- MONDO:0008116
- MONDO:0008029
- MONDO:0001347
- MONDO:0013177
- MONDO:0024771
- MONDO:0011181
- MONDO:0014900
- MONDO:0014141
- MONDO:0030354
- MONDO:0034022
- MONDO:0958077
- MONDO:0009681
- MONDO:0029135
- MONDO:0013071
- MONDO:0008049
- MONDO:0958195
- MONDO:0011028
- MONDO:0958235
- MONDO:0011170
- MONDO:0018006
- MONDO:0009667
- MONDO:0010679
- MONDO:0014101
- MONDO:0030014
- MONDO:0958176
- MONDO:0014144
- MONDO:0023204
- MONDO:0011466
- MONDO:0018098
- MONDO:0014877
- MONDO:0013835
- MONDO:0035650
- MONDO:0008056
- MONDO:0009364
- MONDO:0013157
- MONDO:0014676
- MONDO:0016830
- MONDO:0975918
- MONDO:0008050
- MONDO:0700075
- MONDO:0800318
- MONDO:0014800
- MONDO:0011721
- MONDO:0014474
- MONDO:0013154
- MONDO:0009679
- MONDO:0020336
- MONDO:0035432
- MONDO:0018370
- MONDO:0014023
- MONDO:0012699
- MONDO:0012130
- MONDO:0010912
- MONDO:0013221
- MONDO:0011925
- MONDO:0021083
- MONDO:0019951
- MONDO:0014022
- MONDO:0013390
- MONDO:0011486
- MONDO:0014977
- MONDO:0013156
- MONDO:0000355
- MONDO:0012310
- MONDO:0013072
- MONDO:0013677
- MONDO:0016097
- MONDO:0014120
- MONDO:0004495
- MONDO:0010675
- MONDO:0100584
- MONDO:0016106
- MONDO:0012286
- MONDO:0013686
- MONDO:0020793
- MONDO:0030134
- MONDO:0014945
- MONDO:0019398
- MONDO:0800209
has_descendant_count: 197
has_descendant_label:
- autosomal recessive limb-girdle muscular dystrophy type 2N
- muscular dystrophy, limb-girdle, autosomal recessive 29
- distal myopathy with vocal cord weakness
- juvenile-onset Steinert myotonic dystrophy
- muscular dystrophy, progressive Pectorodorsal
- autosomal recessive limb-girdle muscular dystrophy type 2I
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A6
- congenital muscular dystrophy
- muscular dystrophy-dystroglycanopathy (congenital with intellectual disability),
  type B1
- autosomal recessive limb-girdle muscular dystrophy type 2D
- X-linked scapuloperoneal muscular dystrophy
- myofibrillar myopathy 4
- scapuloperoneal myopathy
- myofibrillar myopathy 3
- autosomal dominant distal myopathy
- muscular dystrophy-dystroglycanopathy, type C
- Bethlem myopathy 1A
- autosomal recessive limb-girdle muscular dystrophy type 2A
- congenital muscular dystrophy with cataracts and intellectual disability
- autosomal recessive myogenic arthrogryposis multiplex congenita
- congenital fibrosis of extraocular muscles
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type a, 11
- DPM3-congenital disorder of glycosylation
- muscular dystrophy, limb-girdle, autosomal recessive 27
- oculopharyngodistal myopathy 3
- muscular dystrophy, limb-girdle, autosomal dominant 4
- congenital muscular dystrophy with hyperlaxity
- Emery-Dreifuss muscular dystrophy 2, autosomal dominant
- muscular dystrophy, limb-girdle, autosomal dominant
- oculopharyngodistal myopathy 4
- muscle-eye-brain disease
- congenital muscular dystrophy without intellectual disability
- autosomal recessive limb-girdle muscular dystrophy type 2H
- megaconial type congenital muscular dystrophy
- autosomal recessive limb-girdle muscular dystrophy type 2W
- muscular dystrophy-dystroglycanopathy (congenital with intellectual disability),
  type B3
- muscular dystrophy, Hemizygous lethal type
- congenital myasthenic syndrome 10
- DMD-related muscular dystrophy
- muscular dystrophy-dystroglycanopathy (congenital with impaired intellectual development),
  type B, 15
- adult-onset Steinert myotonic dystrophy
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A9
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A, 4
- Becker muscular dystrophy
- Bethlem myopathy 1B
- tibial muscular dystrophy
- muscular dystrophy-dystroglycanopathy, type B
- autosomal dominant limb-girdle muscular dystrophy type 1H
- muscular dystrophy, scapulohumeral
- congenital myotonic dystrophy
- autosomal recessive limb-girdle muscular dystrophy type 2C
- childhood-onset Steinert myotonic dystrophy
- X-linked myopathy with postural muscle atrophy
- muscular dystrophy, Mabry type
- autosomal recessive limb-girdle muscular dystrophy type 2X
- facioscapulohumeral muscular dystrophy 1
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A14
- autosomal dominant limb-girdle muscular dystrophy type 1D (DNAJB6)
- childhood-onset progressive contractures-limb-girdle weakness-muscle dystrophy syndrome
- myotonic dystrophy type 2
- muscular dystrophy, pseudohypertrophic, with Internalized capillaries
- LAMA2-related muscular dystrophy
- autosomal dominant limb-girdle muscular dystrophy type 1G
- limb-girdle muscular dystrophy due to POMK deficiency
- muscular dystrophy, limb-girdle, autosomal recessive 23
- distal myopathy with posterior leg and anterior hand involvement
- autosomal recessive limb-girdle muscular dystrophy type 2K
- autosomal recessive limb-girdle muscular dystrophy type 2L
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type a, 8
- autosomal recessive limb-girdle muscular dystrophy type 2B
- Finnish upper limb-onset distal myopathy
- muscular dystrophy-dystroglycanopathy (congenital with intellectual disability),
  type B2
- muscular dystrophy, limb-girdle, autosomal recessive 28
- congenital muscular dystrophy-respiratory failure-skin abnormalities-joint hyperlaxity
  syndrome
- muscular dystrophy-dystroglycanopathy type B6
- congenital muscular dystrophy due to LMNA mutation
- oculopharyngodistal myopathy
- X-linked myopathy with excessive autophagy
- muscular dystrophy, Barnes type
- Ullrich congenital muscular dystrophy 2
- Miyoshi muscular dystrophy 1
- facioscapulohumeral muscular dystrophy 4, digenic
- autosomal recessive limb-girdle muscular dystrophy type 2J
- X-linked Emery-Dreifuss muscular dystrophy
- muscular dystrophy, congenital, with rapid progression
- distal myopathy
- rigid spine muscular dystrophy 1
- Miyoshi myopathy
- congenital muscular dystrophy-infantile cataract-hypogonadism syndrome
- congenital myopathy, Paradas type
- muscular dystrophy-dystroglycanopathy, type A
- autosomal recessive limb-girdle muscular dystrophy type 2P
- muscle-eye-brain disease with bilateral multicystic leucodystrophy
- fibrosis of extraocular muscles, congenital, 3c
- Ullrich congenital muscular dystrophy 1C
- Tukel syndrome
- autosomal recessive limb-girdle muscular dystrophy type 2T
- muscular dystrophy
- limb-girdle muscular dystrophy
- muscular dystrophy-dystroglycanopathy
- facioscapulohumeral muscular dystrophy 2
- myopathy, myofibrillar, 9, with early respiratory failure
- fibrosis of extraocular muscles, congenital, 5
- intermediate collagen VI-related muscular dystrophy
- myotonic dystrophy
- autosomal recessive limb-girdle muscular dystrophy
- congenital muscular dystrophy with intellectual disability
- autosomal recessive limb-girdle muscular dystrophy type 2E
- Bethlem myopathy 1C
- Emery-Dreifuss muscular dystrophy 1, X-linked
- epidermolysis bullosa simplex 5B, with muscular dystrophy
- Miyoshi muscular dystrophy 3
- muscular dystrophy-dystroglycanopathy type B5
- congenital myopathy 7A, myosin storage, autosomal dominant
- autosomal recessive limb-girdle muscular dystrophy type 2O
- nebulin-related early-onset distal myopathy
- autosomal dominant limb-girdle muscular dystrophy type 1F
- congenital-onset Steinert myotonic dystrophy
- oculopharyngeal muscular dystrophy
- Bethlem myopathy
- facioscapulohumeral muscular dystrophy
- congenital muscular dystrophy due to integrin alpha-7 deficiency
- myopathy, distal, 7, adult-onset, X-linked
- fibrosis of extraocular muscles, congenital, 2
- autosomal recessive limb-girdle muscular dystrophy type 2Y
- muscular dystrophy-dystroglycanopathy (congenital with intellectual disability),
  type B14
- facioscapulohumeral muscular dystrophy 3, digenic
- Bethlem myopathy 2
- collagen 6-related congenital muscular dystrophy
- Ullrich congenital muscular dystrophy 1A
- muscular dystrophy-dystroglycanopathy (limb-girdle), type C, 8
- Emery-Dreifuss muscular dystrophy 4, autosomal dominant
- myopathy, distal, infantile-onset
- oculopharyngeal muscular dystrophy 2
- autosomal recessive limb-girdle muscular dystrophy type 2F
- Ullrich congenital muscular dystrophy 1B
- autosomal recessive limb-girdle muscular dystrophy type 2G
- adult-onset distal myopathy due to VCP mutation
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A3
- Duchenne muscular dystrophy
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type a, 12
- muscular dystrophy, limb-girdle, autosomal recessive 26
- oculopharyngeal muscular dystrophy 1
- autosomal recessive limb-girdle muscular dystrophy type R18
- Fukuda-Miyanomae-Nakata syndrome
- distal myopathy, Welander type
- autosomal dominant limb-girdle muscular dystrophy type 1E (DES)
- myopathy, distal, 5
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A, 7
- late-onset Steinert myotonic dystrophy
- myotonic dystrophy type 1
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A1
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A5
- Emery-Dreifuss muscular dystrophy 3, autosomal recessive
- Emery-Dreifuss muscular dystrophy
- asymptomatic hyperckemia-myalgia-rhabdomyolysis syndrome
- MYH7-related skeletal myopathy
- congenital muscular dystrophy caused by variation in POMGNT2
- Emery-Dreifuss muscular dystrophy 6, X-linked
- progressive scapulohumeroperoneal distal myopathy
- distal myopathy with anterior tibial onset
- autosomal recessive limb-girdle muscular dystrophy type 2U
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A2
- arthrogryposis due to muscular dystrophy
- autosomal dominant Emery-Dreifuss muscular dystrophy
- POMGNT2-related limb-girdle muscular dystrophy R24
- KLHL9-related early-onset distal myopathy
- congenital muscular dystrophy with intellectual disability and severe epilepsy
- autosomal recessive limb-girdle muscular dystrophy type 2M
- myofibrillar myopathy 2
- fibrosis of extraocular muscles, congenital, 3A, with or without extraocular involvement
- Miyoshi muscular dystrophy 2
- congenital merosin-deficient muscular dystrophy 1A
- congenital fibrosis of extraocular muscles type 1
- rigid spine syndrome
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type a, 10
- autosomal recessive limb-girdle muscular dystrophy type 2Q
- congenital muscular dystrophy 1B
- autosomal recessive limb-girdle muscular dystrophy type 2R1
- muscular dystrophy-dystroglycanopathy (congenital without intellectual disability),
  type B4
- Ullrich congenital muscular dystrophy
- fibrosis of extraocular muscles, congenital, with synergistic divergence
- Emery-Dreifuss muscular dystrophy 5, autosomal dominant
- Emery-Dreifuss muscular dystrophy 7, autosomal dominant
- symptomatic form of muscular dystrophy of Duchenne and Becker in female carriers
- muscular dystrophy-dystroglycanopathy (congenital with brain and eye anomalies),
  type A13
- myotonic cataract
- muscular dystrophy, cardiac type
- SNUPN-related muscular dystrophy with or without multi-system involvement
- progressive muscular dystrophy
- myopathy, autophagic vacuolar, infantile-onset
- distal myopathy, Tateyama type
- oculopharyngodistal myopathy 1
- oculopharyngodistal myopathy 2
- myopathy, distal, with rimmed vacuoles
- desmin-related myopathy with Mallory body-like inclusions
- fibrosis of extraocular muscles, congenital, 3b
has_phenotype: null
has_phenotype_closure: null
has_phenotype_closure_label: null
has_phenotype_count: 0
has_phenotype_label: null
id: MONDO:0020121
in_taxon: null
in_taxon_label: null
inheritance: null
iri: null
mappings:
- id: Orphanet:98473
  url: https://www.orpha.net/en/disease/detail/98473
- id: icd11.foundation:1464662404
  url: null
- id: MEDGEN:44527
  url: http://identifiers.org/medgen/44527
- id: DOID:9884
  url: http://purl.obolibrary.org/obo/DOID_9884
- id: MESH:D009136
  url: http://identifiers.org/mesh/D009136
- id: NCIT:C84910
  url: http://purl.obolibrary.org/obo/NCIT_C84910
- id: SCTID:73297009
  url: http://identifiers.org/snomedct/73297009
- id: UMLS:C0026850
  url: http://identifiers.org/umls/C0026850
- id: ICD10CM:G71.0
  url: https://icd.codes/icd10cm/G71.0
name: muscular dystrophy
namespace: MONDO
narrow_synonym: null
node_hierarchy:
  sub_classes:
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0008028
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: muscular dystrophy, Barnes type
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0010675
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: muscular dystrophy, cardiac type
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0010676
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: muscular dystrophy, Hemizygous lethal type
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0010677
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: muscular dystrophy, Mabry type
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0010678
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: muscular dystrophy, progressive Pectorodorsal
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0016106
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: progressive muscular dystrophy
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0019950
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: congenital muscular dystrophy
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0018949
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: distal myopathy
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0023204
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: Fukuda-Miyanomae-Nakata syndrome
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0100228
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: LAMA2-related muscular dystrophy
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0700285
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: DMD-related muscular dystrophy
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  super_classes:
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0005336
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: myopathy
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0100546
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: hereditary neuromuscular disease
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
  - broad_synonym: null
    category: biolink:Disease
    deprecated: null
    description: null
    exact_synonym: null
    full_name: null
    has_descendant: null
    has_descendant_count: null
    has_descendant_label: null
    has_phenotype: null
    has_phenotype_closure: null
    has_phenotype_closure_label: null
    has_phenotype_count: null
    has_phenotype_label: null
    id: MONDO:0700223
    in_taxon: null
    in_taxon_label: null
    iri: null
    name: hereditary skeletal muscle disorder
    namespace: null
    narrow_synonym: null
    provided_by: null
    related_synonym: null
    subsets: null
    symbol: null
    synonym: null
    uri: null
    xref: null
provided_by: phenio_nodes
provided_by_link:
  id: phenio
  url: https://monarch-initiative.github.io/monarch-ingest/Sources/phenio/#
related_synonym: null
subsets:
- disease_grouping|gard_rare|ordo_group_of_disorders|otar|rare
symbol: null
synonym: null
uri: http://purl.obolibrary.org/obo/MONDO_0020121
xref:
- DOID:9884
- GARD:7922
- ICD10CM:G71.0
- ICD9:359.1
- MEDGEN:44527
- MESH:D009136
- MedDRA:10028356
- NANDO:1200486
- NANDO:2100233
- NCIT:C84910
- Orphanet:98473
- SCTID:73297009
- UMLS:C0026850
- icd11.foundation:1464662404

"""



from unittest.mock import MagicMock, patch

from fastapi.testclient import TestClient
from httpx import Response

from monarch_py.api.histopheno import router
from monarch_py.datamodels.model import HistoPheno

client = TestClient(router)


def test_histopheno(histopheno):
    with patch.object(
        client,
        "get",
        MagicMock(return_value=Response(200, json=histopheno, headers={"content-type": "application/json"})),
    ):
        response = client.get("/histopheno/HP:0000001")
    assert response.status_code == 200
    assert response.headers["content-type"] == "application/json"
    assert response.json() == histopheno


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_histopheno")
def test_histopheno_params(mock_get_histopheno, histopheno):
    mock_get_histopheno.return_value = HistoPheno(**histopheno)
    client.get("/HP:0000001")
    mock_get_histopheno.assert_called_with("HP:0000001")



"""Meta endpoint for serving HTML with dynamic Open Graph tags to social media crawlers."""

from pathlib import Path

from fastapi import APIRouter, HTTPException, Request
from fastapi.responses import HTMLResponse
from jinja2 import Environment, FileSystemLoader, select_autoescape

from monarch_py.api.config import solr

router = APIRouter(tags=["meta"])

MAX_DESCRIPTION_LENGTH = 300

TEMPLATES_DIR = Path(__file__).parent / "templates"
jinja_env = Environment(
    loader=FileSystemLoader(TEMPLATES_DIR),
    autoescape=select_autoescape(["html", "xml"]),
)


def get_base_url(request: Request) -> str:
    """Derive base URL from the request headers (supports beta/prod via same stack)."""
    scheme = request.headers.get("x-forwarded-proto", request.url.scheme)
    host = request.headers.get("host", request.url.netloc)
    return f"{scheme}://{host}"


def get_default_image(request: Request) -> str:
    """Get the default OG image URL."""
    return f"{get_base_url(request)}/share-thumbnail.jpg"


@router.get("/meta/{entity_id:path}", response_class=HTMLResponse, include_in_schema=False)
async def get_meta_page(entity_id: str, request: Request) -> HTMLResponse:
    """
    Return an HTML page with dynamic Open Graph meta tags for the given entity.

    This endpoint is designed to be called by social media crawlers (Slackbot,
    Twitterbot, etc.) to get entity-specific link previews. Regular users
    should be served the SPA directly by Nginx.

    Args:
        entity_id: The entity identifier (e.g., MONDO:0005148)
        request: The FastAPI request object

    Returns:
        HTML page with entity-specific OG meta tags

    Raises:
        HTTPException: 404 if entity not found
    """
    entity = solr().get_entity(entity_id, extra=False)
    if entity is None:
        raise HTTPException(status_code=404, detail=f"Entity not found: {entity_id}")

    base_url = get_base_url(request)
    entity_url = f"{base_url}/{entity_id}"

    entity_name = entity.name or entity_id
    title = f"{entity_name} | Monarch Initiative"

    description_parts = []
    if entity.name:
        description_parts.append(entity.name)
    if entity.description:
        description_parts.append(entity.description)

    if description_parts:
        description = " - ".join(description_parts)
    else:
        description = f"View {entity_id} on Monarch Initiative"

    if len(description) > MAX_DESCRIPTION_LENGTH:
        description = description[:MAX_DESCRIPTION_LENGTH].rsplit(" ", 1)[0] + "..."

    template = jinja_env.get_template("meta.html")
    html_content = template.render(
        title=title,
        description=description,
        url=entity_url,
        image=get_default_image(request),
    )

    return HTMLResponse(
        content=html_content,
        status_code=200,
        headers={"Cache-Control": "public, max-age=3600"},
    )



import pytest
from unittest.mock import patch

from monarch_py.utils.entity_utils import expansion_patch, get_uri, get_expanded_curie
from monarch_py.datamodels.model import ExpandedCurie


class TestExpansionPatch:
    """Tests for the expansion_patch function."""

    def test_mgi_url_fix(self):
        """Test that MGI URLs with slashes are converted to use colons."""
        url = "https://identifiers.org/MGI/97486"
        result = expansion_patch(url)
        assert result == "https://identifiers.org/MGI:97486"

    def test_mgi_url_already_correct(self):
        """Test that correctly formatted MGI URLs are not modified."""
        url = "https://identifiers.org/MGI:97486"
        result = expansion_patch(url)
        assert result == "https://identifiers.org/MGI:97486"

    def test_phenopacket_url_expansion(self):
        """Test that phenopacket.store URLs are expanded correctly."""
        url = "https://github.com/monarch-initiative/phenopacket-store/blob/main/notebooks/BRCA1.Smith_2020_30696174-III-2"
        result = expansion_patch(url)
        expected = "https://github.com/monarch-initiative/phenopacket-store/blob/main/notebooks/BRCA1/phenopackets/Smith_2020_30696174-III-2.json"
        assert result == expected

    def test_phenopacket_url_with_pedigree_notation(self):
        """Test that pedigree notation dots in filenames are converted to underscores."""
        url = "https://github.com/monarch-initiative/phenopacket-store/blob/main/notebooks/BRCA1.Smith_2020.IV.12"
        result = expansion_patch(url)
        expected = "https://github.com/monarch-initiative/phenopacket-store/blob/main/notebooks/BRCA1/phenopackets/Smith_2020_IV_12.json"
        assert result == expected

    def test_non_matching_url_unchanged(self):
        """Test that URLs not matching any pattern are returned unchanged."""
        url = "https://example.com/some/path"
        result = expansion_patch(url)
        assert result == url


class TestGetUri:
    """Tests for the get_uri function."""

    def test_known_prefix_returns_uri(self):
        """Test that a known prefix returns an expanded URI."""
        result = get_uri("MONDO:0005737")
        assert result is not None
        assert "MONDO" in result

    def test_unknown_prefix_returns_none(self):
        """Test that an unknown prefix returns None."""
        result = get_uri("UNKNOWN_PREFIX:12345")
        assert result is None

    def test_applies_expansion_patch(self):
        """Test that get_uri applies the expansion_patch to the result."""
        result = get_uri("MGI:97486")
        assert result is not None
        # The expansion_patch should fix the MGI URL format
        assert "MGI:97486" in result or "MGI/97486" not in result


class TestGetExpandedCurie:
    """Tests for the get_expanded_curie function."""

    def test_returns_expanded_curie_object(self):
        """Test that get_expanded_curie returns an ExpandedCurie object."""
        result = get_expanded_curie("MONDO:0005737")
        assert isinstance(result, ExpandedCurie)
        assert result.id == "MONDO:0005737"
        assert result.url is not None

    def test_unknown_prefix_returns_none_url(self):
        """Test that an unknown prefix returns ExpandedCurie with None url."""
        result = get_expanded_curie("UNKNOWN_PREFIX:12345")
        assert isinstance(result, ExpandedCurie)
        assert result.id == "UNKNOWN_PREFIX:12345"
        assert result.url is None

    def test_uses_get_uri_for_expansion(self):
        """Test that get_expanded_curie uses get_uri (and thus applies patches)."""
        with patch("monarch_py.utils.entity_utils.get_uri") as mock_get_uri:
            mock_get_uri.return_value = "https://example.com/patched"
            result = get_expanded_curie("TEST:123")
            mock_get_uri.assert_called_once_with("TEST:123")
            assert result.url == "https://example.com/patched"



"""Tests for the meta endpoint that serves dynamic OG tags to crawlers."""

from unittest.mock import patch

import pytest
from fastapi.testclient import TestClient

from monarch_py.api.main import app
from monarch_py.datamodels.model import Node


@pytest.fixture
def client():
    return TestClient(app)


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_returns_html_with_og_tags(mock_get_entity, client, node):
    """Test that /meta/{entity_id} returns HTML with entity-specific OG tags."""
    mock_get_entity.return_value = Node(**node)
    response = client.get("/v3/api/meta/MONDO:0020121")

    assert response.status_code == 200
    assert response.headers["content-type"] == "text/html; charset=utf-8"

    html = response.text
    assert "MONDO:0020121" in html
    assert "muscular dystrophy" in html.lower()
    assert 'og:title' in html
    assert 'og:description' in html
    assert 'og:url' in html
    assert 'testserver/MONDO:0020121' in html


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_returns_404_for_unknown_entity(mock_get_entity, client):
    """Test that /meta/{entity_id} returns 404 for non-existent entities."""
    mock_get_entity.return_value = None
    response = client.get("/v3/api/meta/FAKE:9999999")

    assert response.status_code == 404


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_escapes_html_in_content(mock_get_entity, client):
    """Test that entity content is properly HTML-escaped to prevent XSS."""
    mock_get_entity.return_value = Node(
        id="TEST:001",
        category="biolink:Disease",
        name='<script>alert("xss")</script>',
        description='A "test" <b>entity</b> with & special chars',
        provided_by="test",
        association_counts=[],
    )
    response = client.get("/v3/api/meta/TEST:001")

    assert response.status_code == 200
    html = response.text
    # Jinja2 autoescape should escape angle brackets
    assert "<script>" not in html
    assert "&lt;script&gt;" in html


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_truncates_long_description(mock_get_entity, client):
    """Test that very long descriptions are truncated at a word boundary."""
    long_description = "word " * 200  # 1000 chars, well over the 300 limit
    mock_get_entity.return_value = Node(
        id="TEST:002",
        category="biolink:Disease",
        name="Test Entity",
        description=long_description.strip(),
        provided_by="test",
        association_counts=[],
    )
    response = client.get("/v3/api/meta/TEST:002")

    assert response.status_code == 200
    html = response.text
    assert "..." in html
    # Description (including "Test Entity - " prefix) should be truncated near the limit
    assert long_description.strip() not in html


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_entity_with_no_name(mock_get_entity, client):
    """Test that entities without a name use the entity ID instead."""
    mock_get_entity.return_value = Node(
        id="TEST:003",
        category="biolink:Disease",
        name=None,
        description="A test description",
        provided_by="test",
        association_counts=[],
    )
    response = client.get("/v3/api/meta/TEST:003")

    assert response.status_code == 200
    html = response.text
    assert "TEST:003 | Monarch Initiative" in html
    assert "A test description" in html


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_entity_with_no_description(mock_get_entity, client):
    """Test that entities without a description still produce valid OG tags."""
    mock_get_entity.return_value = Node(
        id="TEST:004",
        category="biolink:Disease",
        name="Test Entity",
        description=None,
        provided_by="test",
        association_counts=[],
    )
    response = client.get("/v3/api/meta/TEST:004")

    assert response.status_code == 200
    html = response.text
    assert "Test Entity | Monarch Initiative" in html
    assert 'og:description' in html


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_entity_with_no_name_or_description(mock_get_entity, client):
    """Test that entities with neither name nor description use fallback text."""
    mock_get_entity.return_value = Node(
        id="TEST:005",
        category="biolink:Disease",
        name=None,
        description=None,
        provided_by="test",
        association_counts=[],
    )
    response = client.get("/v3/api/meta/TEST:005")

    assert response.status_code == 200
    html = response.text
    assert "TEST:005 | Monarch Initiative" in html
    assert "View TEST:005 on Monarch Initiative" in html


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_entity")
def test_meta_endpoint_returns_cache_control_header(mock_get_entity, client, node):
    """Test that the response includes a Cache-Control header."""
    mock_get_entity.return_value = Node(**node)
    response = client.get("/v3/api/meta/MONDO:0020121")

    assert response.status_code == 200
    assert response.headers["cache-control"] == "public, max-age=3600"



import urllib
from unittest.mock import MagicMock, patch

from fastapi.testclient import TestClient
from httpx import Response

from monarch_py.api.association import router
from monarch_py.datamodels.category_enums import AssociationCategory, AssociationPredicate, EntityCategory

client = TestClient(router)


def test_associations(associations):
    with patch.object(
        client,
        "get",
        MagicMock(return_value=Response(200, json=associations, headers={"content-type": "application/json"})),
    ):
        response = client.get("/association?subject=MONDO:0019391&object=HP:0000001")
    assert response.status_code == 200
    assert response.headers["content-type"] == "application/json"
    assert response.json() == associations


@patch("monarch_py.implementations.solr.solr_implementation.SolrImplementation.get_associations")
def test_associations_params(mock_get_assoc):
    """Test that the correct parameters are passed to the monarch api"""
    mock_get_assoc.return_value = MagicMock()

    params = {
        "category": ["biolink:Association", "biolink:GeneToPhenotypicFeatureAssociation"],
        "subject": ["HGNC:0000001", "HGNC:0000002"],
        "predicate": ["biolink:interacts_with"],
        "object": ["MONDO:0000001", "MONDO:0000002"],
        "entity": ["MONDO:0000002", "HGNC:0000001"],
        "subject_category": ["biolink:Disease", "biolink:Gene"],
        "subject_namespace": ["HGNC", "ZFIN"],
        "subject_taxon": ["NCBITaxon:1234", "NCBITaxon:1"],
        "object_taxon": ["NCBITaxon:9876", "NCBITaxon:2"],
        "object_category": ["biolink:Gene", "biolink:PhenotypicFeature"],
        "object_namespace": ["MONDO", "HP"],
        "direct": True,
        "compact": True,
        "facet_fields": [],
        "facet_queries": [],
        "filter_queries": [],
        "offset": 0,
        "limit": 20,
    }
    query_string = urllib.parse.urlencode(params, doseq=True)
    print(query_string)
    client.get(f"/all?{query_string}")

    params["category"] = [AssociationCategory.ASSOCIATION, AssociationCategory.GENE_TO_PHENOTYPIC_FEATURE_ASSOCIATION]
    params["subject_category"] = [EntityCategory.DISEASE, EntityCategory.GENE]
    params["object_category"] = [EntityCategory.GENE, EntityCategory.PHENOTYPIC_FEATURE]
    params["predicate"] = [AssociationPredicate.INTERACTS_WITH]
    mock_get_assoc.assert_called_with(**params)
